@@ -1,6 +1,6 @@
 <?php
 /*
- * $Horde: horde/lib/Horde.php,v 1.118.2.57 2005/11/13 11:48:32 jan Exp $
+ * $Horde: horde/lib/Horde.php,v 1.118.2.55 2004/09/20 20:13:36 slusarz Exp $
  *
  * Copyright 1999-2003 Chuck Hagenbuch <chuck@horde.org>
  * Copyright 1999-2003 Jon Parise <jon@horde.org>
@@ -120,7 +120,7 @@ function _fileCleanup($filename = false, $register = true)
  *
  * @author  Chuck Hagenbuch <chuck@horde.org>
  * @author  Jon Parise <jon@horde.org>
- * @version $Revision: 1.118.2.57 $
+ * @version $Revision: 1.118.2.55 $
  * @since   Horde 1.3
  * @package horde
  */
@@ -234,7 +234,7 @@ class Horde {
 
         $errortext = _("<b>A fatal error has occurred:</b>") . "<br /><br />\n";
         if (is_object($error) && method_exists($error, 'getMessage')) {
-            $errortext .= htmlspecialchars($error->getMessage()) . "<br /><br />\n";
+            $errortext .= $error->getMessage() . "<br /><br />\n";
         }
         $errortext .= sprintf(_("[line %s of %s]"), $line, $file);
 
@@ -864,7 +864,7 @@ HTML;
             (ini_get('output_handler') != 'ob_gzhandler') &&
             (($GLOBALS['browser']->getBrowser() != 'mozilla') ||
              ($GLOBALS['browser']->getMajor() > 4))) {
-            if (function_exists('ob_get_level') && ob_get_level()) {
+            if (ob_get_level()) {
                 ob_end_clean();
             }
             ob_start('ob_gzhandler');
